package DBD::SQLcipher::Constants;

# This module is generated by a script.
# Do not edit manually.

use strict;
use warnings;
use base 'Exporter';
our @EXPORT_OK = (
    # authorizer_action_codes
    qw/
      SQLITE_ALTER_TABLE
      SQLITE_ANALYZE
      SQLITE_ATTACH
      SQLITE_COPY
      SQLITE_CREATE_INDEX
      SQLITE_CREATE_TABLE
      SQLITE_CREATE_TEMP_INDEX
      SQLITE_CREATE_TEMP_TABLE
      SQLITE_CREATE_TEMP_TRIGGER
      SQLITE_CREATE_TEMP_VIEW
      SQLITE_CREATE_TRIGGER
      SQLITE_CREATE_VIEW
      SQLITE_CREATE_VTABLE
      SQLITE_DELETE
      SQLITE_DETACH
      SQLITE_DROP_INDEX
      SQLITE_DROP_TABLE
      SQLITE_DROP_TEMP_INDEX
      SQLITE_DROP_TEMP_TABLE
      SQLITE_DROP_TEMP_TRIGGER
      SQLITE_DROP_TEMP_VIEW
      SQLITE_DROP_TRIGGER
      SQLITE_DROP_VIEW
      SQLITE_DROP_VTABLE
      SQLITE_FUNCTION
      SQLITE_INSERT
      SQLITE_PRAGMA
      SQLITE_READ
      SQLITE_RECURSIVE
      SQLITE_REINDEX
      SQLITE_SAVEPOINT
      SQLITE_SELECT
      SQLITE_TRANSACTION
      SQLITE_UPDATE
    /,

    # authorizer_return_codes
    qw/
      SQLITE_DENY
      SQLITE_IGNORE
    /,

    # extended_result_codes
    qw/
      SQLITE_ABORT_ROLLBACK
      SQLITE_AUTH_USER
      SQLITE_BUSY_RECOVERY
      SQLITE_BUSY_SNAPSHOT
      SQLITE_CANTOPEN_CONVPATH
      SQLITE_CANTOPEN_FULLPATH
      SQLITE_CANTOPEN_ISDIR
      SQLITE_CANTOPEN_NOTEMPDIR
      SQLITE_CONSTRAINT_CHECK
      SQLITE_CONSTRAINT_COMMITHOOK
      SQLITE_CONSTRAINT_FOREIGNKEY
      SQLITE_CONSTRAINT_FUNCTION
      SQLITE_CONSTRAINT_NOTNULL
      SQLITE_CONSTRAINT_PRIMARYKEY
      SQLITE_CONSTRAINT_ROWID
      SQLITE_CONSTRAINT_TRIGGER
      SQLITE_CONSTRAINT_UNIQUE
      SQLITE_CONSTRAINT_VTAB
      SQLITE_CORRUPT_VTAB
      SQLITE_IOERR_ACCESS
      SQLITE_IOERR_BLOCKED
      SQLITE_IOERR_CHECKRESERVEDLOCK
      SQLITE_IOERR_CLOSE
      SQLITE_IOERR_CONVPATH
      SQLITE_IOERR_DELETE
      SQLITE_IOERR_DELETE_NOENT
      SQLITE_IOERR_DIR_CLOSE
      SQLITE_IOERR_DIR_FSYNC
      SQLITE_IOERR_FSTAT
      SQLITE_IOERR_FSYNC
      SQLITE_IOERR_GETTEMPPATH
      SQLITE_IOERR_LOCK
      SQLITE_IOERR_MMAP
      SQLITE_IOERR_NOMEM
      SQLITE_IOERR_RDLOCK
      SQLITE_IOERR_READ
      SQLITE_IOERR_SEEK
      SQLITE_IOERR_SHMLOCK
      SQLITE_IOERR_SHMMAP
      SQLITE_IOERR_SHMOPEN
      SQLITE_IOERR_SHMSIZE
      SQLITE_IOERR_SHORT_READ
      SQLITE_IOERR_TRUNCATE
      SQLITE_IOERR_UNLOCK
      SQLITE_IOERR_WRITE
      SQLITE_LOCKED_SHAREDCACHE
      SQLITE_NOTICE_RECOVER_ROLLBACK
      SQLITE_NOTICE_RECOVER_WAL
      SQLITE_READONLY_CANTLOCK
      SQLITE_READONLY_DBMOVED
      SQLITE_READONLY_RECOVERY
      SQLITE_READONLY_ROLLBACK
      SQLITE_WARNING_AUTOINDEX
    /,

    # flags_for_file_open_operations
    qw/
      SQLITE_OPEN_CREATE
      SQLITE_OPEN_FULLMUTEX
      SQLITE_OPEN_MEMORY
      SQLITE_OPEN_NOMUTEX
      SQLITE_OPEN_PRIVATECACHE
      SQLITE_OPEN_READONLY
      SQLITE_OPEN_READWRITE
      SQLITE_OPEN_SHAREDCACHE
      SQLITE_OPEN_URI
    /,

    # function_flags
    qw/
      SQLITE_DETERMINISTIC
    /,

    # fundamental_datatypes
    qw/
      SQLITE_BLOB
      SQLITE_FLOAT
      SQLITE_INTEGER
      SQLITE_NULL
    /,

    # result_codes
    qw/
      SQLITE_ABORT
      SQLITE_AUTH
      SQLITE_BUSY
      SQLITE_CANTOPEN
      SQLITE_CONSTRAINT
      SQLITE_CORRUPT
      SQLITE_DONE
      SQLITE_EMPTY
      SQLITE_ERROR
      SQLITE_FORMAT
      SQLITE_FULL
      SQLITE_INTERNAL
      SQLITE_INTERRUPT
      SQLITE_IOERR
      SQLITE_LOCKED
      SQLITE_MISMATCH
      SQLITE_MISUSE
      SQLITE_NOLFS
      SQLITE_NOMEM
      SQLITE_NOTADB
      SQLITE_NOTFOUND
      SQLITE_NOTICE
      SQLITE_OK
      SQLITE_PERM
      SQLITE_PROTOCOL
      SQLITE_RANGE
      SQLITE_READONLY
      SQLITE_ROW
      SQLITE_SCHEMA
      SQLITE_TOOBIG
      SQLITE_WARNING
    /,

);

our %EXPORT_TAGS = (
    all => [qw/
      SQLITE_ABORT
      SQLITE_ABORT_ROLLBACK
      SQLITE_ALTER_TABLE
      SQLITE_ANALYZE
      SQLITE_ATTACH
      SQLITE_AUTH
      SQLITE_AUTH_USER
      SQLITE_BLOB
      SQLITE_BUSY
      SQLITE_BUSY_RECOVERY
      SQLITE_BUSY_SNAPSHOT
      SQLITE_CANTOPEN
      SQLITE_CANTOPEN_CONVPATH
      SQLITE_CANTOPEN_FULLPATH
      SQLITE_CANTOPEN_ISDIR
      SQLITE_CANTOPEN_NOTEMPDIR
      SQLITE_CONSTRAINT
      SQLITE_CONSTRAINT_CHECK
      SQLITE_CONSTRAINT_COMMITHOOK
      SQLITE_CONSTRAINT_FOREIGNKEY
      SQLITE_CONSTRAINT_FUNCTION
      SQLITE_CONSTRAINT_NOTNULL
      SQLITE_CONSTRAINT_PRIMARYKEY
      SQLITE_CONSTRAINT_ROWID
      SQLITE_CONSTRAINT_TRIGGER
      SQLITE_CONSTRAINT_UNIQUE
      SQLITE_CONSTRAINT_VTAB
      SQLITE_COPY
      SQLITE_CORRUPT
      SQLITE_CORRUPT_VTAB
      SQLITE_CREATE_INDEX
      SQLITE_CREATE_TABLE
      SQLITE_CREATE_TEMP_INDEX
      SQLITE_CREATE_TEMP_TABLE
      SQLITE_CREATE_TEMP_TRIGGER
      SQLITE_CREATE_TEMP_VIEW
      SQLITE_CREATE_TRIGGER
      SQLITE_CREATE_VIEW
      SQLITE_CREATE_VTABLE
      SQLITE_DELETE
      SQLITE_DENY
      SQLITE_DETACH
      SQLITE_DETERMINISTIC
      SQLITE_DONE
      SQLITE_DROP_INDEX
      SQLITE_DROP_TABLE
      SQLITE_DROP_TEMP_INDEX
      SQLITE_DROP_TEMP_TABLE
      SQLITE_DROP_TEMP_TRIGGER
      SQLITE_DROP_TEMP_VIEW
      SQLITE_DROP_TRIGGER
      SQLITE_DROP_VIEW
      SQLITE_DROP_VTABLE
      SQLITE_EMPTY
      SQLITE_ERROR
      SQLITE_FLOAT
      SQLITE_FORMAT
      SQLITE_FULL
      SQLITE_FUNCTION
      SQLITE_IGNORE
      SQLITE_INSERT
      SQLITE_INTEGER
      SQLITE_INTERNAL
      SQLITE_INTERRUPT
      SQLITE_IOERR
      SQLITE_IOERR_ACCESS
      SQLITE_IOERR_BLOCKED
      SQLITE_IOERR_CHECKRESERVEDLOCK
      SQLITE_IOERR_CLOSE
      SQLITE_IOERR_CONVPATH
      SQLITE_IOERR_DELETE
      SQLITE_IOERR_DELETE_NOENT
      SQLITE_IOERR_DIR_CLOSE
      SQLITE_IOERR_DIR_FSYNC
      SQLITE_IOERR_FSTAT
      SQLITE_IOERR_FSYNC
      SQLITE_IOERR_GETTEMPPATH
      SQLITE_IOERR_LOCK
      SQLITE_IOERR_MMAP
      SQLITE_IOERR_NOMEM
      SQLITE_IOERR_RDLOCK
      SQLITE_IOERR_READ
      SQLITE_IOERR_SEEK
      SQLITE_IOERR_SHMLOCK
      SQLITE_IOERR_SHMMAP
      SQLITE_IOERR_SHMOPEN
      SQLITE_IOERR_SHMSIZE
      SQLITE_IOERR_SHORT_READ
      SQLITE_IOERR_TRUNCATE
      SQLITE_IOERR_UNLOCK
      SQLITE_IOERR_WRITE
      SQLITE_LOCKED
      SQLITE_LOCKED_SHAREDCACHE
      SQLITE_MISMATCH
      SQLITE_MISUSE
      SQLITE_NOLFS
      SQLITE_NOMEM
      SQLITE_NOTADB
      SQLITE_NOTFOUND
      SQLITE_NOTICE
      SQLITE_NOTICE_RECOVER_ROLLBACK
      SQLITE_NOTICE_RECOVER_WAL
      SQLITE_NULL
      SQLITE_OK
      SQLITE_OPEN_CREATE
      SQLITE_OPEN_FULLMUTEX
      SQLITE_OPEN_MEMORY
      SQLITE_OPEN_NOMUTEX
      SQLITE_OPEN_PRIVATECACHE
      SQLITE_OPEN_READONLY
      SQLITE_OPEN_READWRITE
      SQLITE_OPEN_SHAREDCACHE
      SQLITE_OPEN_URI
      SQLITE_PERM
      SQLITE_PRAGMA
      SQLITE_PROTOCOL
      SQLITE_RANGE
      SQLITE_READ
      SQLITE_READONLY
      SQLITE_READONLY_CANTLOCK
      SQLITE_READONLY_DBMOVED
      SQLITE_READONLY_RECOVERY
      SQLITE_READONLY_ROLLBACK
      SQLITE_RECURSIVE
      SQLITE_REINDEX
      SQLITE_ROW
      SQLITE_SAVEPOINT
      SQLITE_SCHEMA
      SQLITE_SELECT
      SQLITE_TOOBIG
      SQLITE_TRANSACTION
      SQLITE_UPDATE
      SQLITE_WARNING
      SQLITE_WARNING_AUTOINDEX
    /],

    authorizer_action_codes => [qw/
      SQLITE_ALTER_TABLE
      SQLITE_ANALYZE
      SQLITE_ATTACH
      SQLITE_COPY
      SQLITE_CREATE_INDEX
      SQLITE_CREATE_TABLE
      SQLITE_CREATE_TEMP_INDEX
      SQLITE_CREATE_TEMP_TABLE
      SQLITE_CREATE_TEMP_TRIGGER
      SQLITE_CREATE_TEMP_VIEW
      SQLITE_CREATE_TRIGGER
      SQLITE_CREATE_VIEW
      SQLITE_CREATE_VTABLE
      SQLITE_DELETE
      SQLITE_DETACH
      SQLITE_DROP_INDEX
      SQLITE_DROP_TABLE
      SQLITE_DROP_TEMP_INDEX
      SQLITE_DROP_TEMP_TABLE
      SQLITE_DROP_TEMP_TRIGGER
      SQLITE_DROP_TEMP_VIEW
      SQLITE_DROP_TRIGGER
      SQLITE_DROP_VIEW
      SQLITE_DROP_VTABLE
      SQLITE_FUNCTION
      SQLITE_INSERT
      SQLITE_PRAGMA
      SQLITE_READ
      SQLITE_RECURSIVE
      SQLITE_REINDEX
      SQLITE_SAVEPOINT
      SQLITE_SELECT
      SQLITE_TRANSACTION
      SQLITE_UPDATE
    /],

    authorizer_return_codes => [qw/
      SQLITE_DENY
      SQLITE_IGNORE
    /],

    extended_result_codes => [qw/
      SQLITE_ABORT_ROLLBACK
      SQLITE_AUTH_USER
      SQLITE_BUSY_RECOVERY
      SQLITE_BUSY_SNAPSHOT
      SQLITE_CANTOPEN_CONVPATH
      SQLITE_CANTOPEN_FULLPATH
      SQLITE_CANTOPEN_ISDIR
      SQLITE_CANTOPEN_NOTEMPDIR
      SQLITE_CONSTRAINT_CHECK
      SQLITE_CONSTRAINT_COMMITHOOK
      SQLITE_CONSTRAINT_FOREIGNKEY
      SQLITE_CONSTRAINT_FUNCTION
      SQLITE_CONSTRAINT_NOTNULL
      SQLITE_CONSTRAINT_PRIMARYKEY
      SQLITE_CONSTRAINT_ROWID
      SQLITE_CONSTRAINT_TRIGGER
      SQLITE_CONSTRAINT_UNIQUE
      SQLITE_CONSTRAINT_VTAB
      SQLITE_CORRUPT_VTAB
      SQLITE_IOERR_ACCESS
      SQLITE_IOERR_BLOCKED
      SQLITE_IOERR_CHECKRESERVEDLOCK
      SQLITE_IOERR_CLOSE
      SQLITE_IOERR_CONVPATH
      SQLITE_IOERR_DELETE
      SQLITE_IOERR_DELETE_NOENT
      SQLITE_IOERR_DIR_CLOSE
      SQLITE_IOERR_DIR_FSYNC
      SQLITE_IOERR_FSTAT
      SQLITE_IOERR_FSYNC
      SQLITE_IOERR_GETTEMPPATH
      SQLITE_IOERR_LOCK
      SQLITE_IOERR_MMAP
      SQLITE_IOERR_NOMEM
      SQLITE_IOERR_RDLOCK
      SQLITE_IOERR_READ
      SQLITE_IOERR_SEEK
      SQLITE_IOERR_SHMLOCK
      SQLITE_IOERR_SHMMAP
      SQLITE_IOERR_SHMOPEN
      SQLITE_IOERR_SHMSIZE
      SQLITE_IOERR_SHORT_READ
      SQLITE_IOERR_TRUNCATE
      SQLITE_IOERR_UNLOCK
      SQLITE_IOERR_WRITE
      SQLITE_LOCKED_SHAREDCACHE
      SQLITE_NOTICE_RECOVER_ROLLBACK
      SQLITE_NOTICE_RECOVER_WAL
      SQLITE_READONLY_CANTLOCK
      SQLITE_READONLY_DBMOVED
      SQLITE_READONLY_RECOVERY
      SQLITE_READONLY_ROLLBACK
      SQLITE_WARNING_AUTOINDEX
    /],

    flags_for_file_open_operations => [qw/
      SQLITE_OPEN_CREATE
      SQLITE_OPEN_FULLMUTEX
      SQLITE_OPEN_MEMORY
      SQLITE_OPEN_NOMUTEX
      SQLITE_OPEN_PRIVATECACHE
      SQLITE_OPEN_READONLY
      SQLITE_OPEN_READWRITE
      SQLITE_OPEN_SHAREDCACHE
      SQLITE_OPEN_URI
    /],

    function_flags => [qw/
      SQLITE_DETERMINISTIC
    /],

    fundamental_datatypes => [qw/
      SQLITE_BLOB
      SQLITE_FLOAT
      SQLITE_INTEGER
      SQLITE_NULL
    /],

    result_codes => [qw/
      SQLITE_ABORT
      SQLITE_AUTH
      SQLITE_BUSY
      SQLITE_CANTOPEN
      SQLITE_CONSTRAINT
      SQLITE_CORRUPT
      SQLITE_DONE
      SQLITE_EMPTY
      SQLITE_ERROR
      SQLITE_FORMAT
      SQLITE_FULL
      SQLITE_INTERNAL
      SQLITE_INTERRUPT
      SQLITE_IOERR
      SQLITE_LOCKED
      SQLITE_MISMATCH
      SQLITE_MISUSE
      SQLITE_NOLFS
      SQLITE_NOMEM
      SQLITE_NOTADB
      SQLITE_NOTFOUND
      SQLITE_NOTICE
      SQLITE_OK
      SQLITE_PERM
      SQLITE_PROTOCOL
      SQLITE_RANGE
      SQLITE_READONLY
      SQLITE_ROW
      SQLITE_SCHEMA
      SQLITE_TOOBIG
      SQLITE_WARNING
    /],

);

1;

__END__

=encoding utf-8

=head1 NAME

DBD::SQLcipher::Constants

=head1 SYNOPSIS

  DBD::SQLcipher::Constants qw/:result_codes/;

=head1 DESCRIPTION

You can import necessary SQLcipher constants from this module. Available tags are C<all>, C<authorizer_action_codes>, C<authorizer_return_codes>, C<extended_result_codes>, C<flags_for_file_open_operations>, C<function_flags>, C<fundamental_datatypes>, C<result_codes>. See L<http://sqlite.org/c3ref/constlist.html> for the complete list of constants.

This module does not export anything by default.

